Note: macro docs are in the main awint crate
Macros
- awi
- A concatenations of components macro, additionally using the source value to
construct an Awi. See
awint::macro_docsfor more. - bits
- A concatenations of components macro, additionally using the source value to
construct a
&'static Bits. - cc
- Copy Corresponding Concatenations of Components Dynamically.
- extawi
- A concatenations of components macro, additionally using the source value to
construct an ExtAwi. See
awint::macro_docsfor more. - inlawi
- A concatenations of components macro, additionally using the source value to
construct an InlAwi. See
awint::macro_docsfor more. - inlawi_
ty - Specifies an InlAwi type in terms of its bitwidth